==> clamcour-0.2.3.tar.gz: clamcour-0.2.3/src/clam.h <==
/*
 *  Copyright (C) 2004 Tony Sin(x) '76 <tony@becrux.com>
 *  All rights reserved.
 *
 */

/*
 *			 GNU GENERAL PUBLIC LICENSE
 *			    Version 2, June 1991
 *
 *  Copyright (C) 1989, 1991 Free Software Foundation, Inc.
 *                           675 Mass Ave, Cambridge, MA 02139, USA
 *  Everyone is permitted to copy and distribute verbatim copies
 *  of this license document, but changing it is not allowed.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.

 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __clam_h__
#define __clam_h__

#ifdef HAVE_CONFIG_H
  #ifndef __main_config_h__
    #define __main_config_h__
    #include "../config.h"
  #endif

  #include <stdio.h>
  #include <clamav.h>
#endif

#include "list.h"

class cClamClient
{
  struct cl_node *root;
  struct cl_stat dbstat;
  struct cl_limits limits;
  int signo;
  bool working;
  int last_error;
  cList *GenerateFileList(FILE *loc_sock);
public:
  cClamClient();
  ~cClamClient();
  bool InitVirDB();
  void FreeDB();
  bool ReloadHashes();
  void TestInfection(int loc_sock);
  const char *GetErrStr();
};

#endif

==> clamcour-0.3.8.tar.gz: clamcour-0.3.8/src/clam.h <==
/*
 *  Copyright (C) 2006 Tony Sin(x) '76 <tony@becrux.com>
 *  All rights reserved.
 *
 */

/*
 *                  GNU GENERAL PUBLIC LICENSE
 *                    Version 2, June 1991
 *
 *  Copyright (C) 1989, 1991 Free Software Foundation, Inc.
 *                           675 Mass Ave, Cambridge, MA 02139, USA
 *  Everyone is permitted to copy and distribute verbatim copies
 *  of this license document, but changing it is not allowed.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.

 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __clam_h__
#define __clam_h__

#ifdef HAVE_CONFIG_H
  #ifndef __main_config_h__
    #define __main_config_h__
    #include "../config.h"
  #endif

  #include <clamav.h>
  #include <pthread.h>
#endif

#define CLAMAV_CLASS_NAME       "cClamAv"
#define CLAMAV_CLASS_NAME_D     "~cClamAv"
#define CLAMAV_TASK_NAME        "cClamAvDBTask"
#define SECS_IN_A_DAY           86400

class cClamAv
{
  static struct cl_node *root;
  static struct cl_limits limits;
  static int counter;
  static int scanTaskCounter;
  static void *taskProc(void *arg);
  static pthread_mutex_t counterMutex;
  static pthread_mutex_t dbMutex;
  static pthread_t thid;
  static unsigned long int sizelimit;

public:
  cClamAv();
  ~cClamAv();
  bool scanFile(const char *filename, const char **virus_name);
};

#endif
